package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbEvaluateAgency;
import com.ruoyi.hezhi.domain.vo.EvaluateAgencyVO;

import java.util.List;
import java.util.Map;

/**
 * 评价机构Service接口
 *
 * @author ruoyi
 * @date 2024-10-23
 */
public interface ITbEvaluateAgencyService
{
    /**
     * 查询评价机构
     *
     * @param evaluateAgencyId 评价机构主键
     * @return 评价机构
     */
    public TbEvaluateAgency selectTbEvaluateAgencyByEvaluateAgencyId(Long evaluateAgencyId);

    /**
     * 查询评价机构列表
     *
     * @param tbEvaluateAgency 评价机构
     * @return 评价机构集合
     */
    public List<TbEvaluateAgency> selectTbEvaluateAgencyList(TbEvaluateAgency tbEvaluateAgency);

    /**
     * 新增评价机构
     *
     * @param tbEvaluateAgency 评价机构
     * @return 结果
     */
    public int insertTbEvaluateAgency(TbEvaluateAgency tbEvaluateAgency);

    /**
     * 修改评价机构
     *
     * @param tbEvaluateAgency 评价机构
     * @return 结果
     */
    public int updateTbEvaluateAgency(TbEvaluateAgency tbEvaluateAgency);

    /**
     * 批量删除评价机构
     *
     * @param evaluateAgencyIds 需要删除的评价机构主键集合
     * @return 结果
     */
    public int deleteTbEvaluateAgencyByEvaluateAgencyIds(Long[] evaluateAgencyIds);

    /**
     * 删除评价机构信息
     *
     * @param evaluateAgencyId 评价机构主键
     * @return 结果
     */
    public int deleteTbEvaluateAgencyByEvaluateAgencyId(Long evaluateAgencyId);

    /**
     * 获取筛选列表
     * @return 结果
     */
    public List<EvaluateAgencyVO> getSelectList();

    /**
     * 评价机构列表
     *
     * @param params 参数
     * @return 评价机构列表
     */
    public List<Map<String, Object>> getEvaluateAgencyList(Map<String, Object> params);

    /**
     * 获取有推荐课程的评价机构列表
     * @return 结果
     */
    public List<Map<String, Object>> getEvaluateAgencyListHasCourse(Map<String, Object> params);

    /**
     * 评价机构详情
     *
     * @param params 参数
     * @return 评价机构详情
     */
    public Map<String, Object> getEvaluateAgencyInfo(Map<String, Object> params);

    /**
     * 根据课程类型获取机构列表
     * @param classType 1-职业考试，2-职业技能
     * @return 结果
     */
    public List<Map<String, Object>> getEvaluateAgencyListByClassType(Integer classType);
}
